<!DOCTYPE TS><TS>
<context>
    <name>String::Accid</name>
    <message>
        <source>Alcacer do Sal, Portugal</source>
        <translation type="obsolete">Alcácer do Sal, Portugal</translation>
    </message>
    <message>
        <source>Barca D&apos;alva, Portugal</source>
        <translation type="obsolete">Barca d&apos;Alva, Portugal</translation>
    </message>
    <message>
        <source>Braganca, Portugal</source>
        <translation type="obsolete">Bragança, Portugal</translation>
    </message>
    <message>
        <source>Caldar Da Rainha, Portugal</source>
        <translation type="obsolete">Caldas da Rainha, Portugal</translation>
    </message>
    <message>
        <source>Castro Daire, Portugal</source>
        <translation type="obsolete">Castro d&apos;Aire, Portugal</translation>
    </message>
    <message>
        <source>Castro Verd, Portugal</source>
        <translation type="obsolete">Castro Verde, Portugal</translation>
    </message>
    <message>
        <source>Covilha, Portugal</source>
        <translation type="obsolete">Covilhâ, Portugal</translation>
    </message>
    <message>
        <source>Evora/C. Coord, Portugal</source>
        <translation type="obsolete">Évora/C. Coord, Portugal</translation>
    </message>
    <message>
        <source>Figueira Da Foz, Portugal</source>
        <translation type="obsolete">Figueira da Foz, Portugal</translation>
    </message>
    <message>
        <source>Flores Acores, Portugal</source>
        <translation type="obsolete">Flores, Açores, Portugal</translation>
    </message>
    <message>
        <source>Gaviao, Portugal</source>
        <translation type="obsolete">Gavião, Portugal</translation>
    </message>
    <message>
        <source>Lajes Acores, Portugal</source>
        <translation type="obsolete">Lajes, Açores, Portugal</translation>
    </message>
    <message>
        <source>Lisbon, Portugal</source>
        <translation type="obsolete">Lisboa, Portugal</translation>
    </message>
    <message>
        <source>London, United Kingdom</source>
        <translation type="obsolete">Londres, Grã Bretanha</translation>
    </message>
    <message>
        <source>Mertola, Portugal</source>
        <translation type="obsolete">Mértola, Portugal</translation>
    </message>
    <message>
        <source>Misterio Da Prai, Portugal</source>
        <translation type="obsolete">Mistério da Praia, Portugal</translation>
    </message>
    <message>
        <source>Olhao, Portugal</source>
        <translation type="obsolete">Olhão, Portugal</translation>
    </message>
    <message>
        <source>Portimao, Portugal</source>
        <translation type="obsolete">Portimão, Portugal</translation>
    </message>
    <message>
        <source>Povoacao, Portugal</source>
        <translation type="obsolete">Povoação, Portugal</translation>
    </message>
    <message>
        <source>Santa Cruz Da Gr, Portugal</source>
        <translation type="obsolete">Santa Cruz da Graça, Portugal</translation>
    </message>
    <message>
        <source>Santa Maria Acores, Portugal</source>
        <translation type="obsolete">Santa Maria, Açores, Portugal</translation>
    </message>
    <message>
        <source>Santarem, Portugal</source>
        <translation type="obsolete">Santarém, Portugal</translation>
    </message>
    <message>
        <source>Sao Joao da Madeira, Portugal</source>
        <translation type="obsolete">São João da Madeira, Portugal</translation>
    </message>
    <message>
        <source>Sao Marcos Da Se, Portugal</source>
        <translation type="obsolete">São Marcos da Sé, Portugal</translation>
    </message>
    <message>
        <source>Sao Vicente, Portugal</source>
        <translation type="obsolete">São Vicente, Portugal</translation>
    </message>
    <message>
        <source>Setubal, Portugal</source>
        <translation type="obsolete">Setúbal, Portugal</translation>
    </message>
    <message>
        <source>Torrao, Portugal</source>
        <translation type="obsolete">Torrão, Portugal</translation>
    </message>
    <message>
        <source>Vila Real De San, Portugal</source>
        <translation type="obsolete">Vila Real de Santo António, Portugal</translation>
    </message>
    <message>
        <source>Western Madeira, Portugal</source>
        <translation type="obsolete">Madeira Oeste, Portugal</translation>
    </message>
</context>
<context>
    <name>String::DayOfWeek</name>
    <message>
        <source>MON</source>
        <translation>SEG</translation>
    </message>
    <message>
        <source>TUE</source>
        <translation>TER</translation>
    </message>
    <message>
        <source>WED</source>
        <translation>QUA</translation>
    </message>
    <message>
        <source>THU</source>
        <translation>QUI</translation>
    </message>
    <message>
        <source>FRI</source>
        <translation>SEX</translation>
    </message>
    <message>
        <source>SAT</source>
        <translation>SÁB</translation>
    </message>
    <message>
        <source>SUN</source>
        <translation>DOM</translation>
    </message>
</context>
<context>
    <name>String::WeatherType</name>
    <message>
        <source>Cloudy</source>
        <translation>Nublado</translation>
    </message>
    <message>
        <source>Mostly Cloudy</source>
        <translation>Muito Nublado</translation>
    </message>
    <message>
        <source>Partly Cloudy</source>
        <translation>Nublado</translation>
    </message>
    <message>
        <source>Light Rain</source>
        <translation>Aguaceiros</translation>
    </message>
    <message>
        <source>Showers</source>
        <translation>Chuviscos</translation>
    </message>
    <message>
        <source>Rain</source>
        <translation>Chuva</translation>
    </message>
    <message>
        <source>AM Showers</source>
        <translation>Chuviscos Matinais</translation>
    </message>
    <message>
        <source>Fog</source>
        <translation>Nevoeiro</translation>
    </message>
    <message>
        <source>Few Showers</source>
        <translation>Alguns Chuviscos</translation>
    </message>
    <message>
        <source>Mostly Sunny</source>
        <translation>Muito Sol</translation>
    </message>
    <message>
        <source>Sunny</source>
        <translation>Sol</translation>
    </message>
    <message>
        <source>Scattered Flurries</source>
        <translation>Nuvens Dispersas</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun</source>
        <translation>Nuvens Manhã/Sol Tarde</translation>
    </message>
    <message>
        <source>Isolated T-Storms</source>
        <translation>Trovoadas Espontâneas</translation>
    </message>
    <message>
        <source>Scattered Thunderstorms</source>
        <translation>Trovoadas Dispersas</translation>
    </message>
    <message>
        <source>PM Showers</source>
        <translation>Chuviscos Tarde</translation>
    </message>
    <message>
        <source>PM Showers/Wind</source>
        <translation>Chuviscos Tarde/Vento</translation>
    </message>
    <message>
        <source>Rain/Snow Showers</source>
        <translation>Chuviscos Chuva/Neve</translation>
    </message>
    <message>
        <source>Few Snow Showers</source>
        <translation>Alguma Neve</translation>
    </message>
    <message>
        <source>Cloudy/Wind</source>
        <translation>Nublado/Vento</translation>
    </message>
    <message>
        <source>Flurries/Wind</source>
        <translation>Nuvens/Vento</translation>
    </message>
    <message>
        <source>Mostly Cloudy/Windy</source>
        <translation>Nublado/Vento</translation>
    </message>
    <message>
        <source>Rain/Thunder</source>
        <translation>Chuva/Trovoada</translation>
    </message>
    <message>
        <source>Partly Cloudy/Windy</source>
        <translation>Pouco Nublado/Vento</translation>
    </message>
    <message>
        <source>AM Rain/Snow Showers</source>
        <translation>Chuviscos Chuva/Neve Manhã</translation>
    </message>
    <message>
        <source>Light Rain/Wind</source>
        <translation>Chuva Ligeira/Vento</translation>
    </message>
    <message>
        <source>Showers/Wind</source>
        <translation>Chuviscos/Vento</translation>
    </message>
    <message>
        <source>Mostly Sunny/Wind</source>
        <translation>Muito Sol/Vento</translation>
    </message>
    <message>
        <source>Flurries</source>
        <translation>Nuvens</translation>
    </message>
    <message>
        <source>Rain/Wind</source>
        <translation>Chuva/Vento</translation>
    </message>
    <message>
        <source>Sct Flurries/Wind</source>
        <translation>Algumas Nuvens/Vento</translation>
    </message>
    <message>
        <source>Sct Strong Storms</source>
        <translation>Alguma Trovoada</translation>
    </message>
    <message>
        <source>PM T-Storms</source>
        <translation>Trovoada Tarde</translation>
    </message>
    <message>
        <source>Thunderstorms</source>
        <translation>Trovoada</translation>
    </message>
    <message>
        <source>Sunny/Windy</source>
        <translation>Sol/Vento</translation>
    </message>
    <message>
        <source>AM Thunderstorms</source>
        <translation>Trovoada Manhã</translation>
    </message>
    <message>
        <source>AM Rain</source>
        <translation>Chuva Manhã</translation>
    </message>
    <message>
        <source>Iso T-Storms/Wind</source>
        <translation>Trovoada/Vento</translation>
    </message>
    <message>
        <source>Rain/Snow</source>
        <translation>Chuva/Neve</translation>
    </message>
    <message>
        <source>Sct T-Storms/Wind</source>
        <translation>Alguma Trovoada/Vento</translation>
    </message>
    <message>
        <source>AM Showers/Wind</source>
        <translation>Chuviscos/Vento</translation>
    </message>
    <message>
        <source>Sct Snow Showers</source>
        <translation>Alguma Neve</translation>
    </message>
    <message>
        <source>Snow to Ice/Wind</source>
        <translation>Neve e Gelo/Vento</translation>
    </message>
    <message>
        <source>Snow to Rain</source>
        <translation>Neve e Gelo</translation>
    </message>
    <message>
        <source>AM Light Rain</source>
        <translation>Chuva Ligeira Manhã</translation>
    </message>
    <message>
        <source>PM Light Rain</source>
        <translation>Chuva Ligeira Tarde</translation>
    </message>
    <message>
        <source>PM Rain</source>
        <translation>Chuva Tarde</translation>
    </message>
    <message>
        <source>Snow Showers</source>
        <translation>Alguma Neve</translation>
    </message>
    <message>
        <source>Rain to Snow</source>
        <translation>Chuva e Neve</translation>
    </message>
    <message>
        <source>PM Rain/Snow</source>
        <translation>Chuva/Neve Tarde</translation>
    </message>
    <message>
        <source>Few Showers/Wind</source>
        <translation>Alguma Chuva/Vento</translation>
    </message>
    <message>
        <source>Snow/Wind</source>
        <translation>Neve/Vento</translation>
    </message>
    <message>
        <source>PM Rain/Snow Showers</source>
        <translation>Alguma Chuva/Neve Tarde</translation>
    </message>
    <message>
        <source>PM Rain/Snow/Wind</source>
        <translation>Chuva/Neve/Vento Tarde</translation>
    </message>
    <message>
        <source>Rain/Snow Showers/Wind</source>
        <translation>Chuva/Alguma Neve/Vento</translation>
    </message>
    <message>
        <source>Rain/Snow/Wind</source>
        <translation>Chuva/Neve/Vento</translation>
    </message>
    <message>
        <source>Light Snow</source>
        <translation>Neve Ligeira</translation>
    </message>
    <message>
        <source>PM Snow</source>
        <translation>Neve Tarde</translation>
    </message>
    <message>
        <source>Few Snow Showers/Wind</source>
        <translation>Alguna Neve/Vento</translation>
    </message>
    <message>
        <source>Light Snow/Wind</source>
        <translation>Neve Ligeira/vento</translation>
    </message>
    <message>
        <source>Wintry Mix</source>
        <translation>Mistura &quot;Wintry&quot;</translation>
    </message>
    <message>
        <source>AM Wintry Mix</source>
        <translation>Mistura &quot;Wintry&quot; Manhã</translation>
    </message>
    <message>
        <source>Hvy Rain/Freezing Rain</source>
        <translation>Chuva Intensa/Chuva Gelada</translation>
    </message>
    <message>
        <source>AM Light Snow</source>
        <translation>Alguma Neve Manhã</translation>
    </message>
    <message>
        <source>Rain/Freezing Rain</source>
        <translation>Chuva/Chuva Gelada</translation>
    </message>
    <message>
        <source>T-Storms/Wind</source>
        <translation>Trovoada/Vento</translation>
    </message>
    <message>
        <source>Sprinkles</source>
        <translation>&quot;Sprinkles&quot;</translation>
    </message>
    <message>
        <source>AM Snow Showers</source>
        <translation>Alguma Neve Manhã</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun/Wind</source>
        <translation>Nuvens Manhã/Sol/Vento Tarde</translation>
    </message>
    <message>
        <source>AM Rain/Snow/Wind</source>
        <translation>Chuva/Neve/Vento Manhã</translation>
    </message>
    <message>
        <source>Rain to Snow/Wind</source>
        <translation>Chuva a Neve/Vento</translation>
    </message>
    <message>
        <source>Snow to Wintry Mix</source>
        <translation>Neve a Mistura &quot;Wintry&quot;</translation>
    </message>
    <message>
        <source>PM Snow Showers/Wind</source>
        <translation>Alguma Neve/Vento Tarde</translation>
    </message>
    <message>
        <source>Snow and Ice to Rain</source>
        <translation>Neve e Gelo a Chuva</translation>
    </message>
    <message>
        <source>Heavy Rain</source>
        <translation>Chuva Pesada</translation>
    </message>
    <message>
        <source>AM Rain/Ice</source>
        <translation>Chuva/Gelo Manhã</translation>
    </message>
    <message>
        <source>AM Snow Showers/Wind</source>
        <translation>Alguma Neve/Vento Manhã</translation>
    </message>
    <message>
        <source>AM Light Snow/Wind</source>
        <translation>Neve Ligeira/Vento Manhã</translation>
    </message>
    <message>
        <source>PM Light Rain/Wind</source>
        <translation>Chuva Ligeira/Vento Tarde</translation>
    </message>
    <message>
        <source>AM Light Wintry Mix</source>
        <translation>Mistura &quot;Wintry&quot; Ligeira Manhã</translation>
    </message>
    <message>
        <source>PM Light Snow/Wind</source>
        <translation>Neve Ligeira/Vento Tarde</translation>
    </message>
    <message>
        <source>Heavy Rain/Wind</source>
        <translation>Chuva Pesada/Vento</translation>
    </message>
    <message>
        <source>PM Snow Shower</source>
        <translation>Neve Tarde</translation>
    </message>
    <message>
        <source>Snow to Rain/Wind</source>
        <translation>Neve a Chuva/Vento</translation>
    </message>
    <message>
        <source>PM Light Rain/Ice</source>
        <translation>Chuva Ligeira/Gelo Tarde</translation>
    </message>
    <message>
        <source>AM Snow</source>
        <translation>Neve Manhã</translation>
    </message>
    <message>
        <source>Snow to Ice</source>
        <translation>Neve a Gelo</translation>
    </message>
    <message>
        <source>Wintry Mix/Wind</source>
        <translation>Mistura &quot;Wintry&quot;/Vento</translation>
    </message>
    <message>
        <source>PM Light Snow</source>
        <translation>Neve Ligeira/Tarde</translation>
    </message>
    <message>
        <source>AM Drizzle</source>
        <translation>&quot;Drizzle&quot; Manhã</translation>
    </message>
    <message>
        <source>Strong Storms/Wind</source>
        <translation>Trovoada Pesada/Vento</translation>
    </message>
    <message>
        <source>PM Drizzle</source>
        <translation>&quot;Drizzle&quot; Tarde</translation>
    </message>
    <message>
        <source>Drizzle</source>
        <translation>&quot;Drizzle&quot;</translation>
    </message>
    <message>
        <source>AM Light Rain/Wind</source>
        <translation>Chuva Ligeira/Vento Manhã</translation>
    </message>
    <message>
        <source>AM Rain/Wind</source>
        <translation>Chuva/Vento Manhã</translation>
    </message>
    <message>
        <source>Wintry Mix to Snow</source>
        <translation>Mistura &quot;Wintry&quot; a Neve</translation>
    </message>
    <message>
        <source>Snow Showers/Windy</source>
        <translation>Neve/Vento</translation>
    </message>
    <message>
        <source>Light Rain Shower</source>
        <translation>Chuviscos Chuva Ligeira</translation>
    </message>
    <message>
        <source>Light Rain with Thunder</source>
        <translation>Chuva Ligeira com Trovoada</translation>
    </message>
    <message>
        <source>Light Drizzle</source>
        <translation>&quot;Drizzle&quot; Ligeiro</translation>
    </message>
    <message>
        <source>Mist</source>
        <translation>&quot;Mist&quot;</translation>
    </message>
    <message>
        <source>Smoke</source>
        <translation>Fumo</translation>
    </message>
    <message>
        <source>Haze</source>
        <translation>Nevoeiro</translation>
    </message>
    <message>
        <source>Light Snow Shower</source>
        <translation>Neve Ligeira</translation>
    </message>
    <message>
        <source>Light Snow Shower/ Windy</source>
        <translation>Neve Ligeira/Vento</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpo</translation>
    </message>
    <message>
        <source>A Few Clouds</source>
        <translation>Algumas Nuvens</translation>
    </message>
    <message>
        <source>Fair</source>
        <translation>Bom</translation>
    </message>
</context>
<context>
    <name>String::WindDirection</name>
    <message>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <source>NNE</source>
        <translation>NNE</translation>
    </message>
    <message>
        <source>NE</source>
        <translation>NE</translation>
    </message>
    <message>
        <source>NEE</source>
        <translation type="obsolete">NEE</translation>
    </message>
    <message>
        <source>E</source>
        <translation>E</translation>
    </message>
    <message>
        <source>SEE</source>
        <translation type="obsolete">SEE</translation>
    </message>
    <message>
        <source>SE</source>
        <translation>SE</translation>
    </message>
    <message>
        <source>SSE</source>
        <translation>SSE</translation>
    </message>
    <message>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <source>SSW</source>
        <translation>SSO</translation>
    </message>
    <message>
        <source>SW</source>
        <translation>SO</translation>
    </message>
    <message>
        <source>SWW</source>
        <translation type="obsolete">SOO</translation>
    </message>
    <message>
        <source>W</source>
        <translation>O</translation>
    </message>
    <message>
        <source>NWW</source>
        <translation type="obsolete">NOO</translation>
    </message>
    <message>
        <source>NW</source>
        <translation>NO</translation>
    </message>
    <message>
        <source>NNW</source>
        <translation>NNO</translation>
    </message>
    <message>
        <source>ENE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ESE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WSW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WNW</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>loading...</source>
        <translation>Aguarde um momento...</translation>
    </message>
    <message>
        <source>[ retrieving weather data ... ]</source>
        <translation>[ a obter a informação meteorológica ... ]</translation>
    </message>
    <message>
        <source>current conditions</source>
        <translation>Condições Actuais</translation>
    </message>
    <message>
        <source>Humidity</source>
        <translation>Humidade</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>Pressão</translation>
    </message>
    <message>
        <source>Wind</source>
        <translation>Vento</translation>
    </message>
    <message>
        <source>Visibility</source>
        <translation>Visibilidade</translation>
    </message>
    <message>
        <source>Wind Chill</source>
        <translation>Temperatura Aparente</translation>
    </message>
    <message>
        <source>UV Index</source>
        <translation>Radiação Ultra-Violeta</translation>
    </message>
    <message>
        <source>extended forecast</source>
        <translation>Próximos Dias</translation>
    </message>
    <message>
        <source>LO</source>
        <translation>Min</translation>
    </message>
    <message>
        <source>HI</source>
        <translation>Max</translation>
    </message>
    <message>
        <source>today&apos;s forecast</source>
        <translation>Previsões para Hoje</translation>
    </message>
    <message>
        <source>tomorrow&apos;s outlook</source>
        <translation>Previsões para Amanhã</translation>
    </message>
    <message>
        <source>Forecast for</source>
        <translation>Previsões para</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation>Imagem de Satélite</translation>
    </message>
    <message>
        <source>Map Unavailable</source>
        <translation>Mapa Indisponível</translation>
    </message>
    <message>
        <source>RAIN</source>
        <translation>CHUVA</translation>
    </message>
    <message>
        <source>MIX/ICE</source>
        <translation>GELO</translation>
    </message>
    <message>
        <source>SNOW</source>
        <translation>NEVE</translation>
    </message>
    <message>
        <source>LIGHT</source>
        <translation>MENOS</translation>
    </message>
    <message>
        <source>HEAVY</source>
        <translation>MAIS</translation>
    </message>
    <message>
        <source>Enter Zip Code</source>
        <translation>Código Postal</translation>
    </message>
    <message>
        <source>weather setup</source>
        <translation>Configurar Meteorologia</translation>
    </message>
    <message>
        <source>To save, press &apos;i&apos; - to cancel, hit escape</source>
        <translation>Para gravar, prima &apos;i&apos;, para cancelar, use o &apos;escape&apos;</translation>
    </message>
    <message>
        <source>COLD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COLDEST</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CLOUD TEMPERATURE</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Weather</name>
    <message>
        <source> is invalid)</source>
        <translation>é invalida)</translation>
    </message>
    <message>
        <source>   No Location Set, Please read the README</source>
        <translation>Tem de especificar uma localização. Em caso de dúvida, leia a documentaçáo</translation>
    </message>
    <message>
        <source>Configuring MythWeather...</source>
        <translation>A configurar o MythWeather...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select unit conversion...</source>
        <translation>Use o cursor para a direita para selecionar a unidade de conversão...</translation>
    </message>
    <message>
        <source>Weather Units</source>
        <translation>Unidades de Meteorologia</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Localização</translation>
    </message>
    <message>
        <source>Aggressiveness</source>
        <translation>Agressividade</translation>
    </message>
    <message>
        <source>Configuration Saved...</source>
        <translation>Configuração Guardada...</translation>
    </message>
    <message>
        <source>Retrieving weather data...</source>
        <translation>A obter os dados meteorológicos...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select your location...</source>
        <translation>Use o cursor para a direita para selecionar a localização...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select the aggressiveness level...</source>
        <translation>Use o cursor para a direita p ara selecionar o nível de agressividade...</translation>
    </message>
    <message>
        <source> 1  High Speed Connection</source>
        <translation>1 Ligação de Banda-Larga</translation>
    </message>
    <message>
        <source> 8  Medium Speed Connection</source>
        <translation>8 Ligação de velocidade média (RDIS)</translation>
    </message>
    <message>
        <source> 15 Low Speed Connection</source>
        <translation>15 Ligação de velocidade baixa (Modem)</translation>
    </message>
    <message>
        <source>Obtaining initial weather data...</source>
        <translation>A obter os dados meteorológicos iniciais...</translation>
    </message>
    <message>
        <source>Updating weather data...</source>
        <translation>A actualizar os dados meteorológicos...</translation>
    </message>
    <message>
        <source>Calm</source>
        <translation>Calmo</translation>
    </message>
    <message>
        <source> at </source>
        <translation> a </translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation>Ilimitado</translation>
    </message>
    <message>
        <source> (minimal)</source>
        <translation> (mínimo)</translation>
    </message>
    <message>
        <source> (moderate)</source>
        <translation> (moderado)</translation>
    </message>
    <message>
        <source> (high)</source>
        <translation> (alta)</translation>
    </message>
    <message>
        <source> (extreme)</source>
        <translation> (extrema)</translation>
    </message>
    <message>
        <source>Today a high of </source>
        <translation>Para hoje, prevê-se uma temperatura máxima de </translation>
    </message>
    <message>
        <source> and a low of </source>
        <translation>° e uma mínima de </translation>
    </message>
    <message>
        <source>. Currently there is a humidity of </source>
        <translation>°, a humidade actual é de </translation>
    </message>
    <message>
        <source>% and the winds are</source>
        <translation>% e o vento </translation>
    </message>
    <message>
        <source> calm.</source>
        <translation>é fraco. </translation>
    </message>
    <message>
        <source> coming in at </source>
        <translation>tem uma velocidade de </translation>
    </message>
    <message>
        <source> mph from the </source>
        <translation> milhas por hora com direcção </translation>
    </message>
    <message>
        <source> Km/h from the </source>
        <translation> kilometros por hora de direcção </translation>
    </message>
    <message>
        <source> Visibility will be unlimited for today.</source>
        <translation>A visibilidade é ilimitada.</translation>
    </message>
    <message>
        <source> Visibility conditions are unknown.</source>
        <translation>As condições de visibilidade são desconhecidas.</translation>
    </message>
    <message>
        <source> There will be a visibility of </source>
        <translation>A visibilidade é de </translation>
    </message>
    <message>
        <source> miles.</source>
        <translation> milhas.</translation>
    </message>
    <message>
        <source> km.</source>
        <translation> km.</translation>
    </message>
    <message>
        <source>SUN</source>
        <translation type="obsolete">DOM</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>MON</source>
        <translation type="obsolete">SEG</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Segunda</translation>
    </message>
    <message>
        <source>TUE</source>
        <translation type="obsolete">TER</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Terça</translation>
    </message>
    <message>
        <source>WED</source>
        <translation type="obsolete">QUA</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Quarta</translation>
    </message>
    <message>
        <source>THU</source>
        <translation type="obsolete">QUI</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Quinta</translation>
    </message>
    <message>
        <source>FRI</source>
        <translation type="obsolete">SEX</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Sexta</translation>
    </message>
    <message>
        <source>SAT</source>
        <translation type="obsolete">SÁB</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Date Error</source>
        <translation>Erro de Data</translation>
    </message>
    <message>
        <source>Tomorrow expect a high of </source>
        <translation>Para amanhã, prevê-se uma temperatura máxima de </translation>
    </message>
    <message>
        <source>Expected conditions: </source>
        <translation>Tempo Previsto: </translation>
    </message>
    <message>
        <source>Weather data from: </source>
        <translation>Dados meteorológicos de: </translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>A Actualizar...</translation>
    </message>
    <message>
        <source> (Not All Information Available)</source>
        <translation>(Não estão disponíveis os dados todos)</translation>
    </message>
    <message>
        <source>*** Invalid Area ID or Server Error ***</source>
        <translation>*** ID de àrea inválida ou erro no servidor ***</translation>
    </message>
    <message>
        <source>Imperial (Fahrenheit, in, etc)</source>
        <translation>Imperial (Fahrenheit, polegadas, etc)</translation>
    </message>
    <message>
        <source>Metric (Celsius, kPa, etc)</source>
        <translation>Métrico (Centígrados, Pascais, etc)</translation>
    </message>
    <message>
        <source>.</source>
        <translation>°.</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <source> F</source>
        <translation>°F</translation>
    </message>
    <message>
        <source> C</source>
        <translation>°C</translation>
    </message>
    <message>
        <source> - PAUSED -</source>
        <translation>- PARADO -</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation type="unfinished">Imagem de Satélite</translation>
    </message>
    <message>
        <source>satellite image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
